==> huhk-1.9.1.tar.gz: huhk-1.9.1/service/app_a/asserts/common/asserts_common_userpointsmanage.py <==
import allure

from service.app_a import unit_request
from service.app_a.sqls.common.sqls_common_userpointsmanage import SqlsCommonUserpointsmanage


class AssertsCommonUserpointsmanage(SqlsCommonUserpointsmanage):
    @allure.step(title="接口返回结果校验")
    def assert_common_userpointsmanage_userpointsexport(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_userpointsmanage_userpointsexport(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["endTime", "logIds", "nickName", "beginTime", "mobile"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_userpointsmanage_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_userpointsmanage_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["mobile", "endTime", "nickName", "beginTime"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_userpointsmanage_manualchangeuserpoints(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_userpointsmanage_manualchangeuserpoints(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["operateMark", "pointChangType", "taskName", "userId", "operateType", "operatePoint"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_userpointsmanage_beforepointsexport(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_userpointsmanage_beforepointsexport(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["endTime", "logIds", "nickName", "beginTime", "mobile"])
        assert True, "数据比较不一致"

==> huhk-1.9.6.tar.gz: huhk-1.9.6/service/app_a/asserts/common/asserts_common_userpointsmanage.py <==
import allure

from service.app_a import unit_request
from service.app_a.sqls.common.sqls_common_userpointsmanage import SqlsCommonUserpointsmanage


class AssertsCommonUserpointsmanage(SqlsCommonUserpointsmanage):
    @allure.step(title="接口返回结果校验")
    def assert_common_userpointsmanage_userpointsexport(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_userpointsmanage_userpointsexport(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["beginTime", "logIds", "mobile", "endTime", "nickName"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_userpointsmanage_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_userpointsmanage_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["nickName", "endTime", "beginTime", "mobile"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_userpointsmanage_manualchangeuserpoints(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_userpointsmanage_manualchangeuserpoints(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["operateType", "operatePoint", "pointChangType", "operateMark", "taskName", "userId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_userpointsmanage_beforepointsexport(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_userpointsmanage_beforepointsexport(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["beginTime", "logIds", "mobile", "endTime", "nickName"])
        assert True, "数据比较不一致"
